@@ -11,6 +11,7 @@ from cli.wallet import HandleWalletFunctions
 from conf.meile_config import MeileGuiConfig
 from typedef.win import CoinsList
 from cli.warp import WarpHandler
+from adapters import HTTPRequests
 
 from kivy.properties import BooleanProperty, StringProperty, ColorProperty
 from kivy.uix.screenmanager import Screen, SlideTransition
@@ -28,7 +29,7 @@ from kivymd.theming import ThemableBehavior
 from kivy.core.window import Window
 from kivymd.uix.behaviors.elevation import RectangularElevationBehavior
 from kivy_garden.mapview import MapMarkerPopup, MapView
-
+from kivymd.toast import toast
 
 import requests
 import sys
@@ -519,7 +520,9 @@ class MainWindow(Screen):
             
         self.old_ip = self.ip
         try: 
-            req = requests.get(ICANHAZURL, timeout=TIMEOUT)
+            Request = HTTPRequests.MakeRequest()
+            http = Request.hadapter()
+            req = http.get(ICANHAZURL)
             self.ip = req.text
         
             self.manager.get_screen(WindowNames.MAIN_WINDOW).ids.new_ip.text = self.ip
